<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Увімкнено режим польоту</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Вимкнено режим польоту</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Увімкнути</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Режим польоту</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Параметри режиму польоту&apos;</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Режим польоту</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Мої пристрої</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Параметри Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Вимкнено</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
        <translation>Якщо ви хочете встановити з&apos;єднання з Bluetooth, спочатку вимкніть «Режим польоту»</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Увімкнути</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Параметри Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>З&apos;єднано %1</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Встановлюємо з&apos;єднання…</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Вимкнено</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>З&apos;єднано з %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не з&apos;єднано</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Вимк.</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Яскравість</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Параметри показу</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Параметри показу</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Яскравість</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Нд</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Пн</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Вт</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Ср</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Чт</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Пт</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Сб</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Додати розкладку клавіатури</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Дата, час</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-годинний час</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-годинний час</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Параметри часу</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Відкрити календар</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Понеділок</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Вівторок</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Середа</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Четвер</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>П&apos;ятниця</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Субота</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Неділя</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>Понеділок</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>вівторок</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>середа</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>четвер</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>п&apos;ятниця</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>субота</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>неділя</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Інші пристрої</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Режим «Не турбувати»</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Параметри режиму «Не турбувати»</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Увімкнути</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Увімкнено режим «Не турбувати»</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Вимкнено режим «Не турбувати»</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Режим «Не турбувати»</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Комфорт для очей</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Комфорт для очей увімкнено</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Комфорт для очей вимкнено</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Параметри показу</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Комфорт для очей</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
    <message>
        <source>On</source>
        <translation>❙</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>○</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Світла</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Темна</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Вимкнути комфорт для очей</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Увімкнути комфорт для очей</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Параметри показу</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Тема: світла</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Тема: темна</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Тема: авто</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Візуальний ефект</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Світла</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Темна</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Модний режим</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Практичний режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Вгорі</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Ліворуч</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Праворуч</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Показувати постійно</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Приховувати</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Розумне приховування</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Розташування</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Параметри бічної панелі</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Немає повідомлень</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Параметри сповіщень</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Сповіщення</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Вимкнути режим «Не турбувати»</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Увімкнути режим «Не турбувати»</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Сповіщення</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Клавіатура</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Налаштування</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Висока швидкодія</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Збалансований</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Заощадження енергії</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Збалансована швидкодія</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Живлення</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Параметри живлення</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Батарея %1, %2 хв залишилося</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Батарея %1, %2 год %3 хв залишилося</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Зарядка %1, %2 хв до повної</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Зарядка %1, %2 год %3 хв до повної</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Ємність %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Заряджається %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Ємність %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Ємність %1, повністю заряджено</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Ємність %1, не заряджається</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Акумулятор</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Заряджання, обчислюємо оцінку часу заряджання</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Обчислюємо залишковий час користування</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>Лишилося %1 хв.</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>Лишилося %1 год. %2 хв.</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Не заряджається</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Повністю заряджено</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Заряджання %1 хв. до повної</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Заряджання %1 год. %2 хв. до повної</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Батарея %1, залишилося %2 год.</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>Лишилося %1 год.</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Заряджання %1, %2 год. до повної</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Заряджання, %1 год. до повної</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Параметри живлення</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Невідомий</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Приспати</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Заблокувати</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Вихід</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Параметри живлення</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Оновити і вимкнути</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Оновити і перезавантажити</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Змінити користувача</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Сьогодні</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Місячний</translation>
    </message>
    <message>
        <source>y</source>
        <translation>р</translation>
    </message>
    <message>
        <source>m</source>
        <translation>м</translation>
    </message>
    <message>
        <source>d</source>
        <translation>д</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Понеділок</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Вівторок</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Середа</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Четвер</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>П&apos;ятниця</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Субота</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Неділя</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Січ</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Лют</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Бер</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Кві</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Тра</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Чер</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Лип</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Сер</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Вер</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Жов</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Лис</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Гру</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Відкрити календар</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>понеділок</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>вівторок</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>середа</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>четвер</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>п&apos;ятниця</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>субота</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>неділя</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Гучність</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Виведення</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Параметри звуку</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Увімкнути звук</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Вимкнути звук</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Параметри звуку</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Немає пристроїв виведення</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Гучність %1</translation>
    </message>
</context>
</TS>